@@ -20,6 +20,7 @@
  * @APPLE_LICENSE_HEADER_END@
  */
 
+#include <IOKit/audio/IOAudioDebug.h>
 #include <IOKit/audio/IOAudioDevice.h>
 #include <IOKit/audio/IOAudioEngine.h>
 #include <IOKit/audio/IOAudioPort.h>
@@ -70,9 +71,9 @@ OSMetaClassDefineReservedUsed(IOAudioDevice, 0);
 OSMetaClassDefineReservedUsed(IOAudioDevice, 1);
 OSMetaClassDefineReservedUsed(IOAudioDevice, 2);
 OSMetaClassDefineReservedUsed(IOAudioDevice, 3);
+OSMetaClassDefineReservedUsed(IOAudioDevice, 4);
+OSMetaClassDefineReservedUsed(IOAudioDevice, 5);
 
-OSMetaClassDefineReservedUnused(IOAudioDevice, 4);
-OSMetaClassDefineReservedUnused(IOAudioDevice, 5);
 OSMetaClassDefineReservedUnused(IOAudioDevice, 6);
 OSMetaClassDefineReservedUnused(IOAudioDevice, 7);
 OSMetaClassDefineReservedUnused(IOAudioDevice, 8);
@@ -101,6 +102,15 @@ OSMetaClassDefineReservedUnused(IOAudioDevice, 30);
 OSMetaClassDefineReservedUnused(IOAudioDevice, 31);
 
 // New code added here
+void IOAudioDevice::setDeviceModelName(const char *modelName)
+{
+    audioDebugIOLog(3, "IOAudioDevice[%p]::setDeviceModelName(%p)", this, modelName);
+
+    if (modelName) {
+        setProperty(kIOAudioDeviceModelIDKey, modelName);
+    }
+}
+
 void IOAudioDevice::setDeviceTransportType(const UInt32 transportType)
 {
     if (transportType) {
@@ -119,9 +129,7 @@ void IOAudioDevice::setIdleAudioSleepTime(unsigned long long sleepDelay)
 {
 	assert(reserved);
 
-#ifdef DEBUG_CALLS
-	IOLog ("IOAudioDevice[%p]::setIdleAudioSleepTime: sleepDelay = %lx%lx\n", this, (UInt32)(sleepDelay >> 32), (UInt32)sleepDelay);
-#endif
+	audioDebugIOLog(3, "IOAudioDevice[%p]::setIdleAudioSleepTime: sleepDelay = %lx%lx", this, (UInt32)(sleepDelay >> 32), (UInt32)sleepDelay);
 	if (reserved->idleSleepDelayTime != sleepDelay) {
 		reserved->idleSleepDelayTime = sleepDelay;
 		scheduleIdleAudioSleep();
@@ -142,9 +150,7 @@ void IOAudioDevice::scheduleIdleAudioSleep(void)
 
 	assert(reserved);
 
-#ifdef DEBUG_CALLS
-	IOLog ("IOAudioDevice[%p]::scheduleIdleAudioSleep: idleSleepDelayTime = %lx%lx\n", this, (UInt32)(reserved->idleSleepDelayTime >> 32), (UInt32)reserved->idleSleepDelayTime);
-#endif
+	audioDebugIOLog(3, "IOAudioDevice[%p]::scheduleIdleAudioSleep: idleSleepDelayTime = %lx%lx", this, (UInt32)(reserved->idleSleepDelayTime >> 32), (UInt32)reserved->idleSleepDelayTime);
 	if (reserved->idleSleepDelayTime == 0) {
 		// For backwards compatibility, or drivers that don't care, tell them about idle right away.
 		initiatePowerStateChange();
@@ -178,9 +184,7 @@ void IOAudioDevice::idleAudioSleepHandlerTimer(OSObject *owner, IOTimerEventSour
 	audioDevice = OSDynamicCast(IOAudioDevice, owner);
 	assert(audioDevice);
 
-#ifdef DEBUG_CALLS
-	IOLog ("IOAudioDevice[%p]idleAudioSleepHandlerTimer: pendingPowerState = %d, idleSleepDelayTime = %lx%lx\n", audioDevice, audioDevice->pendingPowerState, (UInt32)(audioDevice->reserved->idleSleepDelayTime >> 32), (UInt32)audioDevice->reserved->idleSleepDelayTime);
-#endif
+	audioDebugIOLog(3, "IOAudioDevice[%p]idleAudioSleepHandlerTimer: pendingPowerState = %d, idleSleepDelayTime = %lx%lx", audioDevice, audioDevice->pendingPowerState, (UInt32)(audioDevice->reserved->idleSleepDelayTime >> 32), (UInt32)audioDevice->reserved->idleSleepDelayTime);
 	if (audioDevice->reserved->idleSleepDelayTime != kNoIdleAudioPowerDown &&
 		audioDevice->getPendingPowerState () == kIOAudioDeviceIdle) {
 		// If we're still idle, tell the device to go idle now that the requested amount of time has elapsed.
@@ -192,23 +196,25 @@ void IOAudioDevice::idleAudioSleepHandlerTimer(OSObject *owner, IOTimerEventSour
 
 void IOAudioDevice::setConfigurationApplicationBundle(const char *bundleID)
 {
-#ifdef DEBUG_CALLS
-    IOLog("IOAudioDevice[%p]::setConfigurationApplicationBundle(%p)\n", this, bundleID);
-#endif
+    audioDebugIOLog(3, "IOAudioDevice[%p]::setConfigurationApplicationBundle(%p)", this, bundleID);
 
     if (bundleID) {
         setProperty(kIOAudioDeviceConfigurationAppKey, bundleID);
     }
 }
 
+// OSMetaClassDefineReservedUsed(IOAudioDevice, 4);
+void IOAudioDevice::setDeviceCanBeDefault(UInt32 defaultsFlags)
+{
+	setProperty(kIOAudioDeviceCanBeDefaults, defaultsFlags, sizeof(UInt32) * 8);
+}
+
 // Original code here...
 const IORegistryPlane *IOAudioDevice::gIOAudioPlane = 0;
 
 bool IOAudioDevice::init(OSDictionary *properties)
 {
-#ifdef DEBUG_CALLS
-    IOLog("IOAudioDevice[%p]::init(%p)\n", this, properties);
-#endif
+    audioDebugIOLog(3, "IOAudioDevice[%p]::init(%p)", this, properties);
 
     if (!super::init(properties)) {
         return false;
@@ -254,9 +260,7 @@ bool IOAudioDevice::init(OSDictionary *properties)
 
 void IOAudioDevice::free()
 {
-#ifdef DEBUG_CALLS
-    IOLog("IOAudioDevice[%p]::free()\n", this);
-#endif
+    audioDebugIOLog(3, "IOAudioDevice[%p]::free()", this);
 
     if (audioEngines) {
         deactivateAllAudioEngines();
@@ -316,9 +320,7 @@ void IOAudioDevice::free()
 
 bool IOAudioDevice::initHardware(IOService *provider)
 {
-#ifdef DEBUG_CALLS
-    IOLog("IOAudioDevice[%p]::initHardware(%p)\n", this, provider);
-#endif
+    audioDebugIOLog(3, "IOAudioDevice[%p]::initHardware(%p)", this, provider);
 
     return true;
 }
@@ -330,9 +332,7 @@ bool IOAudioDevice::start(IOService *provider)
         {1, IOPMDeviceUsable, IOPMPowerOn, IOPMPowerOn, 0, 0, 0, 0, 0, 0, 0, 0}
     };
     
-#ifdef DEBUG_CALLS
-    IOLog("IOAudioDevice[%p]::start(%p)\n", this, provider);
-#endif
+    audioDebugIOLog(3, "IOAudioDevice[%p]::start(%p)", this, provider);
 
     if (!super::start(provider)) {
         return false;
@@ -351,6 +351,8 @@ bool IOAudioDevice::start(IOService *provider)
     
     workLoop->addEventSource(commandGate);
 
+	setDeviceCanBeDefault (kIOAudioDeviceCanBeDefaultInput | kIOAudioDeviceCanBeDefaultOutput | kIOAudioDeviceCanBeSystemOutput);
+
     if (!initHardware(provider)) {
         return false;
     }
@@ -374,9 +376,7 @@ bool IOAudioDevice::start(IOService *provider)
 
 void IOAudioDevice::stop(IOService *provider)
 {    
-#ifdef DEBUG_CALLS
-    IOLog("IOAudioDevice[%p]::stop(%p)\n", this, provider);
-#endif
+    audioDebugIOLog(3, "IOAudioDevice[%p]::stop(%p)", this, provider);
     
     if (timerEventSource) {
         if (workLoop) {
@@ -419,9 +419,7 @@ void IOAudioDevice::stop(IOService *provider)
 
 bool IOAudioDevice::willTerminate(IOService *provider, IOOptionBits options)
 {
-#ifdef DEBUG_CALLS
-    IOLog("IOAudioDevice[%p]::willTerminate(%p, %lx)\n", this, provider, options);
-#endif
+    audioDebugIOLog(3, "IOAudioDevice[%p]::willTerminate(%p, %lx)", this, provider, options);
 
     OSCollectionIterator *engineIterator;
     
@@ -447,9 +445,7 @@ IOReturn IOAudioDevice::setPowerState(unsigned long powerStateOrdinal, IOService
 {
     IOReturn result = IOPMCannotRaisePower;
     
-#ifdef DEBUG_CALLS
-    IOLog("IOAudioDevice[%p]::setPowerState(%lu, %p)\n", this, powerStateOrdinal, device);
-#endif
+    audioDebugIOLog(3, "IOAudioDevice[%p]::setPowerState(%lu, %p)", this, powerStateOrdinal, device);
     
     if (!duringStartup) {
         if (powerStateOrdinal >= NUM_POWER_STATES) {
@@ -487,9 +483,7 @@ IOReturn IOAudioDevice::protectedSetPowerState(unsigned long powerStateOrdinal,
 {
     IOReturn result = IOPMAckImplied;
 
-#ifdef DEBUG_CALLS
-    IOLog("IOAudioDevice[%p]::protectedSetPowerState(%lu, %p)\n", this, powerStateOrdinal, device);
-#endif
+    audioDebugIOLog(3, "IOAudioDevice[%p]::protectedSetPowerState(%lu, %p)", this, powerStateOrdinal, device);
     
     if (asyncPowerStateChangeInProgress) {
         waitForPendingPowerStateChange();
@@ -542,9 +536,7 @@ IOReturn IOAudioDevice::protectedSetPowerState(unsigned long powerStateOrdinal,
 
 void IOAudioDevice::waitForPendingPowerStateChange()
 {
-#ifdef DEBUG_CALLS
-    IOLog("IOAudioDevice[%p]::waitForPendingPowerStateChange()\n", this);
-#endif
+    audioDebugIOLog(3, "IOAudioDevice[%p]::waitForPendingPowerStateChange()", this);
 
     if (asyncPowerStateChangeInProgress) {
         IOCommandGate *cg;
@@ -565,9 +557,7 @@ IOReturn IOAudioDevice::initiatePowerStateChange(UInt32 *microsecondsUntilComple
 {
     IOReturn result = kIOReturnSuccess;
 
-#ifdef DEBUG_CALLS
-    IOLog("IOAudioDevice[%p]::initiatePowerStateChange(%p) - current = %d - pending = %d\n", this, microsecondsUntilComplete, currentPowerState, pendingPowerState);
-#endif
+    audioDebugIOLog(3, "IOAudioDevice[%p]::initiatePowerStateChange(%p) - current = %d - pending = %d", this, microsecondsUntilComplete, currentPowerState, pendingPowerState);
     
     if (currentPowerState != pendingPowerState) {
         UInt32 localMicsUntilComplete, *micsUntilComplete = NULL;
@@ -630,9 +620,7 @@ IOReturn IOAudioDevice::protectedCompletePowerStateChange()
 {
     IOReturn result = kIOReturnSuccess;
 
-#ifdef DEBUG_CALLS
-    IOLog("IOAudioDevice[%p]::protectedCompletePowerStateChange() - current = %d - pending = %d\n", this, currentPowerState, pendingPowerState);
-#endif
+    audioDebugIOLog(3, "IOAudioDevice[%p]::protectedCompletePowerStateChange() - current = %d - pending = %d", this, currentPowerState, pendingPowerState);
 
     if (currentPowerState != pendingPowerState) {
 		IOCommandGate *cg;
@@ -705,9 +693,7 @@ IOAudioDevicePowerState IOAudioDevice::getPendingPowerState()
 
 void IOAudioDevice::audioEngineStarting()
 {
-#ifdef DEBUG_CALLS
-    IOLog("IOAudioDevice[%p]::audioEngineStarting() - numRunningAudioEngines = %ld\n", this, numRunningAudioEngines + 1);
-#endif
+    audioDebugIOLog(3, "IOAudioDevice[%p]::audioEngineStarting() - numRunningAudioEngines = %ld", this, numRunningAudioEngines + 1);
 
     numRunningAudioEngines++;
     
@@ -733,9 +719,7 @@ void IOAudioDevice::audioEngineStarting()
 
 void IOAudioDevice::audioEngineStopped()
 {
-#ifdef DEBUG_CALLS
-    IOLog("IOAudioDevice[%p]::audioEngineStopped() - numRunningAudioEngines = %ld\n", this, numRunningAudioEngines - 1);
-#endif
+    audioDebugIOLog(3, "IOAudioDevice[%p]::audioEngineStopped() - numRunningAudioEngines = %ld", this, numRunningAudioEngines - 1);
 
     numRunningAudioEngines--;
     
@@ -764,20 +748,30 @@ IOCommandGate *IOAudioDevice::getCommandGate() const
 
 void IOAudioDevice::setDeviceName(const char *deviceName)
 {
-#ifdef DEBUG_CALLS
-    IOLog("IOAudioDevice[%p]::setDeviceName(%p)\n", this, deviceName);
-#endif
+    audioDebugIOLog(3, "IOAudioDevice[%p]::setDeviceName(%p)", this, deviceName);
 
     if (deviceName) {
         setProperty(kIOAudioDeviceNameKey, deviceName);
+		if (NULL == getProperty (kIOAudioDeviceModelIDKey)) {
+			int			stringLen;
+			char *		string;
+
+			stringLen = 1;
+			stringLen += strlen (deviceName) + 1;
+			stringLen += strlen (getName ());
+			string = (char *)IOMalloc (stringLen);
+			strcpy (string, getName ());
+			strcat (string, ":");
+			strcat (string, deviceName);
+			setDeviceModelName (string);
+			IOFree (string, stringLen);
+		}
     }
 }
 
 void IOAudioDevice::setDeviceShortName(const char *shortName)
 {
-#ifdef DEBUG_CALLS
-    IOLog("IOAudioDevice[%p]::setDeviceName(%p)\n", this, shortName);
-#endif
+    audioDebugIOLog(3, "IOAudioDevice[%p]::setDeviceShortName(%p)", this, shortName);
 
     if (shortName) {
         setProperty(kIOAudioDeviceShortNameKey, shortName);
@@ -786,9 +780,7 @@ void IOAudioDevice::setDeviceShortName(const char *shortName)
 
 void IOAudioDevice::setManufacturerName(const char *manufacturerName)
 {
-#ifdef DEBUG_CALLS
-    IOLog("IOAudioDevice[%p]::setManufacturerName(%p)\n", this, manufacturerName);
-#endif
+    audioDebugIOLog(3, "IOAudioDevice[%p]::setManufacturerName(%p)", this, manufacturerName);
 
     if (manufacturerName) {
         setProperty(kIOAudioDeviceManufacturerNameKey, manufacturerName);
@@ -802,9 +794,7 @@ IOReturn IOAudioDevice::activateAudioEngine(IOAudioEngine *audioEngine)
 
 IOReturn IOAudioDevice::activateAudioEngine(IOAudioEngine *audioEngine, bool shouldStartAudioEngine)
 {
-#ifdef DEBUG_CALLS
-    IOLog("IOAudioDevice[%p]::activateAudioEngine(%p, %d)\n", this, audioEngine, shouldStartAudioEngine);
-#endif
+    audioDebugIOLog(3, "IOAudioDevice[%p]::activateAudioEngine(%p, %d)", this, audioEngine, shouldStartAudioEngine);
 
     if (!audioEngine || !audioEngines) {
         return kIOReturnBadArgument;
@@ -835,9 +825,7 @@ void IOAudioDevice::deactivateAllAudioEngines()
 {
     OSCollectionIterator *engineIterator;
     
-#ifdef DEBUG_CALLS
-    IOLog("IOAudioDevice[%p]::deactivateAllAudioEngines()\n", this);
-#endif
+    audioDebugIOLog(3, "IOAudioDevice[%p]::deactivateAllAudioEngines()", this);
 
     if (!audioEngines) {
         return;
@@ -918,9 +906,7 @@ void IOAudioDevice::detachAllAudioPorts()
 
 void IOAudioDevice::flushAudioControls()
 {
-#ifdef DEBUG_CALLS
-    IOLog("IOAudioDevice[%p]::flushAudioControls()\n", this);
-#endif
+    audioDebugIOLog(3, "IOAudioDevice[%p]::flushAudioControls()", this);
 
     if (audioPorts) {
         OSCollectionIterator *portIterator;
@@ -988,10 +974,10 @@ IOReturn IOAudioDevice::addTimerEvent(OSObject *target, TimerEvent event, Absolu
     IOReturn result = kIOReturnSuccess;
     IOAudioTimerEvent *newEvent;
     
-#ifdef DEBUG_CALLS
+#ifdef DEBUG
     UInt64 newInt;
     absolutetime_to_nanoseconds(interval, &newInt);
-    IOLog("IOAudioDevice::addTimerEvent(%p, %p, %lums)\n", target, event, (UInt32)(newInt/1000000));
+    audioDebugIOLog(3, "IOAudioDevice::addTimerEvent(%p, %p, %lums)", target, event, (UInt32)(newInt/1000000));
 #endif
 
     if (!event) {
@@ -1036,11 +1022,11 @@ IOReturn IOAudioDevice::addTimerEvent(OSObject *target, TimerEvent event, Absolu
         
         result = timerEventSource->wakeAtTime(nextTimerFire);
         
-#ifdef DEBUG_TIMER
+#ifdef DEBUG
         {
             UInt64 nanos;
             absolutetime_to_nanoseconds(minimumInterval, &nanos);
-            IOLog("IOAudioDevice::addTimerEvent() - scheduling timer to fire in %lums - previousTimerFire = {%ld,%lu}\n", (UInt32) (nanos / 1000000), previousTimerFire.hi, previousTimerFire.lo);
+            audioDebugIOLog(5, "IOAudioDevice::addTimerEvent() - scheduling timer to fire in %lums - previousTimerFire = {%ld,%lu}", (UInt32) (nanos / 1000000), previousTimerFire.hi, previousTimerFire.lo);
         }
 #endif
 
@@ -1061,11 +1047,11 @@ IOReturn IOAudioDevice::addTimerEvent(OSObject *target, TimerEvent event, Absolu
         if (CMP_ABSOLUTETIME(&desiredNextFire, &currentNextFire) < 0) {
             assert(timerEventSource);
             
-#ifdef DEBUG_TIMER
+#ifdef DEBUG
             {
                 UInt64 nanos;
                 absolutetime_to_nanoseconds(interval, &nanos);
-                IOLog("IOAudioDevice::addTimerEvent() - scheduling timer to fire in %lums at {%ld,%lu} - previousTimerFire = {%ld,%lu}\n", (UInt32) (nanos / 1000000), desiredNextFire.hi, desiredNextFire.lo, previousTimerFire.hi, previousTimerFire.lo);
+                audioDebugIOLog(5, "IOAudioDevice::addTimerEvent() - scheduling timer to fire in %lums at {%ld,%lu} - previousTimerFire = {%ld,%lu}", (UInt32) (nanos / 1000000), desiredNextFire.hi, desiredNextFire.lo, previousTimerFire.hi, previousTimerFire.lo);
             }
 #endif
 
@@ -1083,9 +1069,7 @@ void IOAudioDevice::removeTimerEvent(OSObject *target)
 {
     IOAudioTimerEvent *removedTimerEvent;
     
-#ifdef DEBUG_CALLS
-    IOLog("IOAudioDevice::removeTimerEvent(%p)\n", target);
-#endif
+    audioDebugIOLog(3, "IOAudioDevice::removeTimerEvent(%p)", target);
     
     if (!timerEvents) {
         return;
@@ -1128,7 +1112,7 @@ void IOAudioDevice::removeTimerEvent(OSObject *target)
             nextTimerFire = previousTimerFire;
             ADD_ABSOLUTETIME(&nextTimerFire, &minimumInterval);
             
-#ifdef DEBUG_TIMER
+#ifdef DEBUG
             {
                 AbsoluteTime now, then;
                 UInt64 nanos, mi;
@@ -1138,11 +1122,11 @@ void IOAudioDevice::removeTimerEvent(OSObject *target)
                 if (CMP_ABSOLUTETIME(&then, &now)) {
                     SUB_ABSOLUTETIME(&then, &now);
                     absolutetime_to_nanoseconds(then, &nanos);
-                    IOLog("IOAudioDevice::removeTimerEvent() - scheduling timer to fire in %lums at {%ld,%lu} - previousTimerFire = {%ld,%lu} - interval=%lums\n", (UInt32) (nanos / 1000000), nextTimerFire.hi, nextTimerFire.lo, previousTimerFire.hi, previousTimerFire.lo, (UInt32)(mi/1000000));
+                    audioDebugIOLog(5, "IOAudioDevice::removeTimerEvent() - scheduling timer to fire in %lums at {%ld,%lu} - previousTimerFire = {%ld,%lu} - interval=%lums", (UInt32) (nanos / 1000000), nextTimerFire.hi, nextTimerFire.lo, previousTimerFire.hi, previousTimerFire.lo, (UInt32)(mi/1000000));
                 } else {
                     SUB_ABSOLUTETIME(&now, &then);
                     absolutetime_to_nanoseconds(now, &nanos);
-                    IOLog("IOAudioDevice::removeTimerEvent() - scheduling timer to fire in -%lums - previousTimerFire = {%ld,%lu}\n", (UInt32) (nanos / 1000000), previousTimerFire.hi, previousTimerFire.lo);
+                    audioDebugIOLog(5, "IOAudioDevice::removeTimerEvent() - scheduling timer to fire in -%lums - previousTimerFire = {%ld,%lu}", (UInt32) (nanos / 1000000), previousTimerFire.hi, previousTimerFire.lo);
                 }
             }
 #endif
@@ -1156,9 +1140,7 @@ void IOAudioDevice::removeTimerEvent(OSObject *target)
 
 void IOAudioDevice::removeAllTimerEvents()
 {
-#ifdef DEBUG_CALLS
-    IOLog("IOAudioDevice[%p]::removeAllTimerEvents()\n", this);
-#endif
+    audioDebugIOLog(3, "IOAudioDevice[%p]::removeAllTimerEvents()", this);
 
     if (timerEventSource) {
         timerEventSource->cancelTimeout();
@@ -1183,7 +1165,7 @@ void IOAudioDevice::timerFired(OSObject *target, IOTimerEventSource *sender)
 void IOAudioDevice::dispatchTimerEvents(bool force)
 {
     if (timerEvents) {
-#ifdef DEBUG_TIMER
+#ifdef DEBUG
         AbsoluteTime now, delta;
         UInt64 nanos;
         
@@ -1191,7 +1173,7 @@ void IOAudioDevice::dispatchTimerEvents(bool force)
         delta = now;
         SUB_ABSOLUTETIME(&delta, &previousTimerFire);
         absolutetime_to_nanoseconds(delta, &nanos);
-        IOLog("IOAudioDevice::dispatchTimerEvents() - woke up %lums after last fire - now = {%ld,%lu} - previousFire = {%ld,%lu}\n", (UInt32)(nanos / 1000000), now.hi, now.lo, previousTimerFire.hi, previousTimerFire.lo);
+        audioDebugIOLog(5, "IOAudioDevice::dispatchTimerEvents() - woke up %lums after last fire - now = {%ld,%lu} - previousFire = {%ld,%lu}", (UInt32)(nanos / 1000000), now.hi, now.lo, previousTimerFire.hi, previousTimerFire.lo);
 #endif
 
         if (force || (getPowerState() != kIOAudioDeviceSleep)) {
@@ -1225,7 +1207,7 @@ void IOAudioDevice::dispatchTimerEvents(bool force)
         
                 assert(timerEventSource);
                 
-#ifdef DEBUG_TIMER
+#ifdef DEBUG
                 {
                     AbsoluteTime later;
                     UInt64 mi;
@@ -1234,11 +1216,11 @@ void IOAudioDevice::dispatchTimerEvents(bool force)
                     if (CMP_ABSOLUTETIME(&later, &now)) {
                         SUB_ABSOLUTETIME(&later, &now);
                         absolutetime_to_nanoseconds(later, &nanos);
-                        IOLog("IOAudioDevice::dispatchTimerEvents() - scheduling timer to fire in %lums at {%ld,%lu} - previousTimerFire = {%ld,%lu} - interval=%lums\n", (UInt32) (nanos / 1000000), nextTimerFire.hi, nextTimerFire.lo, previousTimerFire.hi, previousTimerFire.lo, (UInt32)(mi/1000000));
+                        audioDebugIOLog(5, "IOAudioDevice::dispatchTimerEvents() - scheduling timer to fire in %lums at {%ld,%lu} - previousTimerFire = {%ld,%lu} - interval=%lums", (UInt32) (nanos / 1000000), nextTimerFire.hi, nextTimerFire.lo, previousTimerFire.hi, previousTimerFire.lo, (UInt32)(mi/1000000));
                     } else {
                         SUB_ABSOLUTETIME(&now, &later);
                         absolutetime_to_nanoseconds(now, &nanos);
-                        IOLog("IOAudioDevice::dispatchTimerEvents() - scheduling timer to fire in -%lums - previousTimerFire = {%ld,%lu}\n", (UInt32) (nanos / 1000000), previousTimerFire.hi, previousTimerFire.lo);
+                        audioDebugIOLog(5, "IOAudioDevice::dispatchTimerEvents() - scheduling timer to fire in -%lums - previousTimerFire = {%ld,%lu}", (UInt32) (nanos / 1000000), previousTimerFire.hi, previousTimerFire.lo);
                     }
                 }
 #endif
