@@ -20,17 +20,13 @@
  * @APPLE_LICENSE_HEADER_END@
  */
 
-#ifdef DEBUG
-#define DEBUG_OUTPUT
-#endif
-
+#include <IOKit/audio/IOAudioDebug.h>
 #include <IOKit/audio/IOAudioStream.h>
 #include <IOKit/audio/IOAudioEngine.h>
 #include <IOKit/audio/IOAudioEngineUserClient.h>
 #include <IOKit/audio/IOAudioControl.h>
 #include <IOKit/audio/IOAudioTypes.h>
 #include <IOKit/audio/IOAudioDefines.h>
-#include <IOKit/audio/IOAudioDebug.h>
 
 #include <IOKit/IOLib.h>
 #include <IOKit/IOWorkLoop.h>
@@ -151,9 +147,7 @@ IOReturn IOAudioStream::setFormat(const IOAudioStreamFormat *streamFormat, const
     IOAudioStreamFormatDesc formatDesc;
 	IOAudioStreamFormatExtension validFormatExtension;
     
-#ifdef DEBUG_CALLS
-    IOLog("IOAudioStream[%p]::setFormat(%p, %p)\n", this, streamFormat, formatDict);
-#endif
+    audioDebugIOLog(3, "IOAudioStream[%p]::setFormat(%p, %p)", this, streamFormat, formatDict);
 
     if (!streamFormat || !formatDict) {
         return kIOReturnBadArgument;
@@ -375,9 +369,18 @@ void IOAudioStream::addAvailableFormat(const IOAudioStreamFormat *streamFormat,
                 sampleRateDict->release();
                 sampleRateDict = IOAudioEngine::createDictionaryFromSampleRate(maxRate);
                 if (sampleRateDict) {
+					OSArray *newAvailableFormats;
+					OSArray *oldAvailableFormats;
+
+					oldAvailableFormats = availableFormatDictionaries;
+					newAvailableFormats = OSArray::withArray(availableFormatDictionaries);
+					
                     formatDict->setObject(gMaximumSampleRateKey, sampleRateDict);
                     sampleRateDict->release();
-                    availableFormatDictionaries->setObject(formatDict);
+                    newAvailableFormats->setObject(formatDict);
+					availableFormatDictionaries = newAvailableFormats;
+					setProperty(kIOAudioStreamAvailableFormatsKey, availableFormatDictionaries);
+					oldAvailableFormats->release();
                     if (streamFormat->fNumChannels > maxNumChannels) {
                         maxNumChannels = streamFormat->fNumChannels;
                     }
@@ -397,23 +400,19 @@ bool IOAudioStream::validateFormat(IOAudioStreamFormat *streamFormat, IOAudioStr
 {
     bool foundFormat = false;
     
-#ifdef DEBUG_CALLS
-    IOLog("IOAudioStream[%p]::validateFormat(%p, %p, %p)\n", this, streamFormat, formatExtension, formatDesc);
-#endif
+    audioDebugIOLog(3, "IOAudioStream[%p]::validateFormat(%p, %p, %p)", this, streamFormat, formatExtension, formatDesc);
     
     if (streamFormat && availableFormats && (numAvailableFormats > 0)) {
         UInt32 formatIndex;
 
         for (formatIndex = 0; formatIndex < numAvailableFormats; formatIndex++) {
-#ifdef DEBUG
-			IOLog ("%ld: streamFormat->fNumChannels = %ld\n", availableFormats[formatIndex].format.fNumChannels, streamFormat->fNumChannels);
-			IOLog ("0x%lx: streamFormat->fSampleFormat = 0x%lx\n", availableFormats[formatIndex].format.fSampleFormat, streamFormat->fSampleFormat);
-			IOLog ("0x%lx: streamFormat->fNumericRepresentation = 0x%lx\n", availableFormats[formatIndex].format.fNumericRepresentation, streamFormat->fNumericRepresentation);
-			IOLog ("%d: streamFormat->fBitDepth = %d\n", availableFormats[formatIndex].format.fBitDepth, streamFormat->fBitDepth);
-			IOLog ("%d: streamFormat->fBitWidth = %d\n", availableFormats[formatIndex].format.fBitWidth, streamFormat->fBitWidth);
-			IOLog ("%d: streamFormat->fAlignment = %d\n", availableFormats[formatIndex].format.fAlignment, streamFormat->fAlignment);
-			IOLog ("%d: streamFormat->fByteOrder = %d\n", availableFormats[formatIndex].format.fByteOrder, streamFormat->fByteOrder);
-#endif
+			audioDebugIOLog(3, "%ld: streamFormat->fNumChannels = %ld", availableFormats[formatIndex].format.fNumChannels, streamFormat->fNumChannels);
+			audioDebugIOLog(3, "0x%lx: streamFormat->fSampleFormat = 0x%lx", availableFormats[formatIndex].format.fSampleFormat, streamFormat->fSampleFormat);
+			audioDebugIOLog(3, "0x%lx: streamFormat->fNumericRepresentation = 0x%lx", availableFormats[formatIndex].format.fNumericRepresentation, streamFormat->fNumericRepresentation);
+			audioDebugIOLog(3, "%d: streamFormat->fBitDepth = %d", availableFormats[formatIndex].format.fBitDepth, streamFormat->fBitDepth);
+			audioDebugIOLog(3, "%d: streamFormat->fBitWidth = %d", availableFormats[formatIndex].format.fBitWidth, streamFormat->fBitWidth);
+			audioDebugIOLog(3, "%d: streamFormat->fAlignment = %d", availableFormats[formatIndex].format.fAlignment, streamFormat->fAlignment);
+			audioDebugIOLog(3, "%d: streamFormat->fByteOrder = %d", availableFormats[formatIndex].format.fByteOrder, streamFormat->fByteOrder);
             if ((availableFormats[formatIndex].format.fNumChannels == streamFormat->fNumChannels)
              && (availableFormats[formatIndex].format.fSampleFormat == streamFormat->fSampleFormat)
              && (availableFormats[formatIndex].format.fNumericRepresentation == streamFormat->fNumericRepresentation)
@@ -452,9 +451,7 @@ IOReturn IOAudioStream::mixOutputSamples(const void *sourceBuf, void *mixBuf, UI
 
 void IOAudioStream::setSampleLatency(UInt32 numSamples)
 {
-#ifdef DEBUG_CALLS
-    IOLog("IOAudioStream[%p]::setSampleLatency(0x%lx)\n", this, numSamples);
-#endif
+    audioDebugIOLog(3, "IOAudioStream[%p]::setSampleLatency(0x%lx)", this, numSamples);
     setProperty(kIOAudioStreamSampleLatencyKey, numSamples, sizeof(UInt32)*8);
 }
 
@@ -660,6 +657,8 @@ IOAudioStreamFormat *IOAudioStream::createFormatFromDictionary(const OSDictionar
 
 bool IOAudioStream::initWithAudioEngine(IOAudioEngine *engine, IOAudioStreamDirection dir, UInt32 startChannelID, const char *streamDescription, OSDictionary *properties)
 {
+	UInt32				streamID;
+
     if (!gNumChannelsKey) {
         initKeys();
     }
@@ -713,7 +712,10 @@ bool IOAudioStream::initWithAudioEngine(IOAudioEngine *engine, IOAudioStreamDire
     }
     setProperty(kIOAudioStreamAvailableFormatsKey, availableFormatDictionaries);
     
-    setProperty(kIOAudioStreamIDKey, (UInt32)this, sizeof(UInt32)*8);
+	// This needs to change to passing up a token rather than the "this" pointer.
+	streamID = engine->getNextStreamID (this);
+    setProperty(kIOAudioStreamIDKey, streamID, sizeof(UInt32)*8);
+//    setProperty(kIOAudioStreamIDKey, (UInt32)this, sizeof(UInt32)*8);
     
     streamAvailable = true;
     setProperty(kIOAudioStreamAvailableKey, (UInt8)1, sizeof(UInt8)*8);
@@ -827,9 +829,7 @@ IOReturn IOAudioStream::setProperties(OSObject *properties)
     OSDictionary *props;
     IOReturn result = kIOReturnSuccess;
     
-#ifdef DEBUG_CALLS
-    IOLog("IOAudioStream[%p]::setProperties(%p)\n", this, properties);
-#endif
+    audioDebugIOLog(3, "IOAudioStream[%p]::setProperties(%p)", this, properties);
 
     if (properties && (props = OSDynamicCast(OSDictionary, properties))) {
         OSCollectionIterator *iterator;
@@ -1073,9 +1073,7 @@ void IOAudioStream::updateNumClients()
 IOReturn IOAudioStream::addClient(IOAudioClientBuffer *clientBuffer)
 {
     IOReturn result = kIOReturnBadArgument;
-#ifdef DEBUG_CALLS
-    IOLog("IOAudioStream[%p]::addClient(%p)\n", this, clientBuffer);
-#endif
+    audioDebugIOLog(3, "IOAudioStream[%p]::addClient(%p)", this, clientBuffer);
 
     if (clientBuffer) {
         assert(clientBuffer->audioStream == this);
@@ -1132,9 +1130,7 @@ IOReturn IOAudioStream::addClient(IOAudioClientBuffer *clientBuffer)
 
 void IOAudioStream::removeClient(IOAudioClientBuffer *clientBuffer)
 {
-#ifdef DEBUG_CALLS
-    IOLog("IOAudioStream[%p]::removeClient(%p)\n", this, clientBuffer);
-#endif
+    audioDebugIOLog(3, "IOAudioStream[%p]::removeClient(%p)", this, clientBuffer);
 
     if (clientBuffer) {
         IOAudioClientBuffer *tmpClientBuffer, *previousClientBuffer = NULL;
@@ -1196,7 +1192,7 @@ void IOAudioStream::removeClient(IOAudioClientBuffer *clientBuffer)
 		// clear these values for bug 2851917
 		clientBuffer->previousClip = NULL;
 		clientBuffer->nextClip = NULL;
-		clientBuffer->nextClient = NULL;       
+		clientBuffer->nextClient = NULL;
 		unlockStreamForIO();
     }
 }
@@ -1212,7 +1208,7 @@ void dumpList(IOAudioClientBuffer *start)
     
     tmp = start;
     while (tmp) {
-        IOLog("(%lx,%lx)\n", tmp->mixedPosition.fLoopCount, tmp->mixedPosition.fSampleFrame);
+        audioDebugIOLog(3, "(%lx,%lx)", tmp->mixedPosition.fLoopCount, tmp->mixedPosition.fSampleFrame);
         tmp = tmp->nextClip;
     }
 }
@@ -1224,7 +1220,7 @@ void validateList(IOAudioClientBuffer *start)
     tmp = start;
     while (tmp) {
         if (tmp->nextClip && (CMP_IOAUDIOENGINEPOSITION(&tmp->mixedPosition, &tmp->nextClip->mixedPosition) > 0)) {
-            IOLog("IOAudioStream: ERROR - client buffer list not sorted!\n");
+            audioDebugIOLog(3, "IOAudioStream: ERROR - client buffer list not sorted!");
             dumpList(start);
             break;
         }
@@ -1288,10 +1284,8 @@ IOReturn IOAudioStream::processOutputSamples(IOAudioClientBuffer *clientBuffer,
 {
     IOReturn result = kIOReturnSuccess;
 	
-#ifdef DEBUG_OUTPUT_CALLS
-    //IOLog("IOAudioStream[%p]::processOutputSamples(%p, 0x%lx)\n", this, clientBuffer, firstSampleFrame);
-    //IOLog("m(%lx,%lx,%lx)\n", loopCount, firstSampleFrame, clientBuffer->numSampleFrames);
-#endif
+    //audioDebugIOLog(6, "IOAudioStream[%p]::processOutputSamples(%p, 0x%lx)", this, clientBuffer, firstSampleFrame);
+    //audioDebugIOLog(6, "m(%lx,%lx,%lx)", loopCount, firstSampleFrame, clientBuffer->numSampleFrames);
 
     assert(direction == kIOAudioStreamDirectionOutput);
     if (clientBuffer) {
@@ -1316,9 +1310,7 @@ IOReturn IOAudioStream::processOutputSamples(IOAudioClientBuffer *clientBuffer,
                 // If firstSampleFrame is not the same as the previous mixed position sample frame,
                 // then adjust it to the firstSampleFrame - looping if necessary
                 if ((clientBuffer->mixedPosition.fSampleFrame != firstSampleFrame) || (clientBuffer->mixedPosition.fLoopCount != loopCount)) {
-#ifdef DEBUG
-                    IOLog("IOAudioStream[%p]::processOutputSamples(%p) - Mix start position (%lx,%lx) is not previous mixed position (%lx,%lx)\n", this, clientBuffer, loopCount, firstSampleFrame, clientBuffer->mixedPosition.fLoopCount, clientBuffer->mixedPosition.fSampleFrame);
-#endif
+                    audioDebugIOLog(6, "IOAudioStream[%p]::processOutputSamples(%p) - Mix start position (%lx,%lx) is not previous mixed position (%lx,%lx)", this, clientBuffer, loopCount, firstSampleFrame, clientBuffer->mixedPosition.fLoopCount, clientBuffer->mixedPosition.fSampleFrame);
                     clientBuffer->mixedPosition.fLoopCount = loopCount;
                     clientBuffer->mixedPosition.fSampleFrame = firstSampleFrame;
                 }
@@ -1339,10 +1331,8 @@ IOReturn IOAudioStream::processOutputSamples(IOAudioClientBuffer *clientBuffer,
                     } else {
                         clientBuffer->mixedPosition.fLoopCount = clientBufferListEnd->mixedPosition.fLoopCount;
                     }
-#ifdef DEBUG
-    IOLog("IOAudioStream[%p]::processOutputSamples(%p) - more than one buffer behind (%lx,%lx) adjusting to (%lx,%lx)\n", this, clientBuffer, clientBufferListEnd->mixedPosition.fLoopCount, clientBufferListEnd->mixedPosition.fSampleFrame, clientBuffer->mixedPosition.fLoopCount, firstSampleFrame);
-    //dumpList(clientBufferListStart);
-#endif
+					audioDebugIOLog(6, "IOAudioStream[%p]::processOutputSamples(%p) - more than one buffer behind (%lx,%lx) adjusting to (%lx,%lx)", this, clientBuffer, clientBufferListEnd->mixedPosition.fLoopCount, clientBufferListEnd->mixedPosition.fSampleFrame, clientBuffer->mixedPosition.fLoopCount, firstSampleFrame);
+					//dumpList(clientBufferListStart);
                 }
             }
             
@@ -1353,10 +1343,10 @@ IOReturn IOAudioStream::processOutputSamples(IOAudioClientBuffer *clientBuffer,
                     if (clientBuffer->mixedPosition.fSampleFrame < clippedPosition.fSampleFrame) {
                         audioEngine->resetClipPosition(this, clientBuffer->mixedPosition.fSampleFrame);
 
-#ifdef DEBUG_OUTPUT
+#ifdef DEBUG
                         UInt32 samplesMissed;
                         samplesMissed = clippedPosition.fSampleFrame - clientBuffer->mixedPosition.fSampleFrame;
-                        IOLog("IOAudioStream[%p]::processOutputSamples(%p) - Reset clip position (%lx,%lx)->(%lx,%lx) - %lx samples.\n", this, clientBuffer, clippedPosition.fLoopCount, clippedPosition.fSampleFrame, clientBuffer->mixedPosition.fLoopCount, clientBuffer->mixedPosition.fSampleFrame, samplesMissed);
+                        audioDebugIOLog(6, "IOAudioStream[%p]::processOutputSamples(%p) - Reset clip position (%lx,%lx)->(%lx,%lx) - %lx samples.", this, clientBuffer, clippedPosition.fLoopCount, clippedPosition.fSampleFrame, clientBuffer->mixedPosition.fLoopCount, clientBuffer->mixedPosition.fSampleFrame, samplesMissed);
 #endif
 
                         clippedPosition = clientBuffer->mixedPosition;
@@ -1364,11 +1354,11 @@ IOReturn IOAudioStream::processOutputSamples(IOAudioClientBuffer *clientBuffer,
                 } else if (clientBuffer->mixedPosition.fLoopCount < clippedPosition.fLoopCount) {
                     audioEngine->resetClipPosition(this, clientBuffer->mixedPosition.fSampleFrame);
                     
-#ifdef DEBUG_OUTPUT
+#ifdef DEBUG
                     UInt32 samplesMissed;
                     samplesMissed = (clippedPosition.fLoopCount - clientBuffer->mixedPosition.fLoopCount - 1) * numSampleFramesPerBuffer;
                     samplesMissed += clippedPosition.fSampleFrame + numSampleFramesPerBuffer - clientBuffer->mixedPosition.fSampleFrame;
-                    IOLog("IOAudioStream[%p]::processOutputSamples(%p) - Reset clip position (%lx,%lx)->(%lx,%lx) - %lx samples.\n", this, clientBuffer, clippedPosition.fLoopCount, clippedPosition.fSampleFrame, clientBuffer->mixedPosition.fLoopCount, clientBuffer->mixedPosition.fSampleFrame, samplesMissed);
+                    audioDebugIOLog(6, "IOAudioStream[%p]::processOutputSamples(%p) - Reset clip position (%lx,%lx)->(%lx,%lx) - %lx samples.", this, clientBuffer, clippedPosition.fLoopCount, clippedPosition.fSampleFrame, clientBuffer->mixedPosition.fLoopCount, clientBuffer->mixedPosition.fSampleFrame, samplesMissed);
 #endif
 
                     clippedPosition = clientBuffer->mixedPosition;
@@ -1385,17 +1375,17 @@ IOReturn IOAudioStream::processOutputSamples(IOAudioClientBuffer *clientBuffer,
             
             if (numSamplesToMix > 0) {
 /*
-#ifdef DEBUG_OUTPUT
+#ifdef DEBUG
                 UInt32 currentSampleFrame = audioEngine->getCurrentSampleFrame();
                 if (currentSampleFrame > firstSampleFrame) {
                     if ((firstSampleFrame + clientBuffer->numSampleFrames) > currentSampleFrame) {
-                        //IOLog("IOAudioStream[%p]::processOutputSamples(%p) - Error: Some samples already played: first=%lx num=%lx curr=%lx\n", this, clientBuffer, firstSampleFrame, clientBuffer->numSampleFrames, currentSampleFrame);
-                        IOLog("mix() missed first=%lx num=%lx curr=%lx\n", firstSampleFrame, clientBuffer->numSampleFrames, currentSampleFrame);
+                        //audioDebugIOLog(6, "IOAudioStream[%p]::processOutputSamples(%p) - Error: Some samples already played: first=%lx num=%lx curr=%lx", this, clientBuffer, firstSampleFrame, clientBuffer->numSampleFrames, currentSampleFrame);
+                        audioDebugIOLog(6, "mix() missed first=%lx num=%lx curr=%lx", firstSampleFrame, clientBuffer->numSampleFrames, currentSampleFrame);
                     }
                 } else {
                     if ((clientBuffer->numSampleFrames + firstSampleFrame) > (currentSampleFrame + numSampleFramesPerBuffer)) {
-                        //IOLog("IOAudioStream[%p]::processOutputSamples(%p) - Error: Some samples already played: first=%lx num=%lx curr=%lx\n", this, clientBuffer, firstSampleFrame, clientBuffer->numSampleFrames, currentSampleFrame);
-                        IOLog("mix() missed first=%lx num=%lx curr=%lx\n", firstSampleFrame, clientBuffer->numSampleFrames, currentSampleFrame);
+                        //audioDebugIOLog(6, "IOAudioStream[%p]::processOutputSamples(%p) - Error: Some samples already played: first=%lx num=%lx curr=%lx", this, clientBuffer, firstSampleFrame, clientBuffer->numSampleFrames, currentSampleFrame);
+                        audioDebugIOLog(6, "mix() missed first=%lx num=%lx curr=%lx", firstSampleFrame, clientBuffer->numSampleFrames, currentSampleFrame);
                     }
                 }
 #endif
@@ -1567,9 +1557,7 @@ void IOAudioStream::resetClipInfo()
 
 void IOAudioStream::clipIfNecessary()
 {
-#ifdef DEBUG_OUTPUT_CALLS
-    //IOLog("IOAudioStream[%p]::clipIfNecessary()\n", this);
-#endif
+    //audioDebugIOLog(6, "IOAudioStream[%p]::clipIfNecessary()", this);
 
     if (clientBufferListStart != NULL) {
         // Only try to clip if there is not an unmixed buffer
@@ -1580,7 +1568,7 @@ void IOAudioStream::clipIfNecessary()
                 clippedPosition = startingPosition;
             }
             
-#ifdef DEBUG_OUTPUT
+#ifdef DEBUG
             IOAudioClientBuffer *tmp;
             
             tmp = clientBufferListStart->nextClip;
@@ -1592,14 +1580,14 @@ void IOAudioStream::clipIfNecessary()
                     if (clientBufferListStart->mixedPosition.fSampleFrame > clippedPosition.fSampleFrame) {
                         if ((tmp->mixedPosition.fSampleFrame > clippedPosition.fSampleFrame) &&
                             (clientBufferListStart->mixedPosition.fSampleFrame > tmp->mixedPosition.fSampleFrame)) {
-                            IOLog("IOAudioStream[%p]::clipIfNecessary() - Error: Clipping across future buffer boundary - glitching! (%lx,%lx)->(%lx,%lx) buf=(%lx,%lx)\n", this, clippedPosition.fLoopCount, clippedPosition.fSampleFrame, clientBufferListStart->mixedPosition.fLoopCount, clientBufferListStart->mixedPosition.fSampleFrame, tmp->mixedPosition.fLoopCount, tmp->mixedPosition.fSampleFrame);
+                            audioDebugIOLog(6, "IOAudioStream[%p]::clipIfNecessary() - Error: Clipping across future buffer boundary - glitching! (%lx,%lx)->(%lx,%lx) buf=(%lx,%lx)", this, clippedPosition.fLoopCount, clippedPosition.fSampleFrame, clientBufferListStart->mixedPosition.fLoopCount, clientBufferListStart->mixedPosition.fSampleFrame, tmp->mixedPosition.fLoopCount, tmp->mixedPosition.fSampleFrame);
                             dumpList(clientBufferListStart);
                             break;
                         }
                     } else if (clippedPosition.fSampleFrame > clientBufferListStart->mixedPosition.fSampleFrame) {
                         if ((tmp->mixedPosition.fSampleFrame < clientBufferListStart->mixedPosition.fSampleFrame) ||
                             (tmp->mixedPosition.fSampleFrame > clippedPosition.fSampleFrame)) {
-                            IOLog("IOAudioStream[%p]::clipIfNecessary() - Error: Clipping across future buffer boundary - glitching! (%lx,%lx)->(%lx,%lx) buf=(%lx,%lx)\n", this, clippedPosition.fLoopCount, clippedPosition.fSampleFrame, clientBufferListStart->mixedPosition.fLoopCount, clientBufferListStart->mixedPosition.fSampleFrame, tmp->mixedPosition.fLoopCount, tmp->mixedPosition.fSampleFrame);
+                            audioDebugIOLog(6, "IOAudioStream[%p]::clipIfNecessary() - Error: Clipping across future buffer boundary - glitching! (%lx,%lx)->(%lx,%lx) buf=(%lx,%lx)", this, clippedPosition.fLoopCount, clippedPosition.fSampleFrame, clientBufferListStart->mixedPosition.fLoopCount, clientBufferListStart->mixedPosition.fSampleFrame, tmp->mixedPosition.fLoopCount, tmp->mixedPosition.fSampleFrame);
                             dumpList(clientBufferListStart);
                             break;
                         }
@@ -1632,7 +1620,7 @@ void IOAudioStream::clipIfNecessary()
 /*
 	static UInt32 lastSampleFrame;
 	if (clippedPosition.fSampleFrame != lastSampleFrame) {
-		IOLog ("Family sample frames wrong %ld %ld\n", clippedPosition.fSampleFrame, lastSampleFrame);
+		audioDebugIOLog(3, "Family sample frames wrong %ld %ld", clippedPosition.fSampleFrame, lastSampleFrame);
 	}
 	lastSampleFrame = clippedPosition.fSampleFrame + (clientBufferListStart->mixedPosition.fSampleFrame - clippedPosition.fSampleFrame);
 */
@@ -1642,7 +1630,6 @@ void IOAudioStream::clipIfNecessary()
                     clipOutputSamples(clippedPosition.fSampleFrame, clientBufferListStart->mixedPosition.fSampleFrame - clippedPosition.fSampleFrame);
                     clippedPosition.fSampleFrame = clientBufferListStart->mixedPosition.fSampleFrame;
                 } else if (clientBufferListStart->mixedPosition.fSampleFrame < clippedPosition.fSampleFrame) {
-                    //!!FIXME!! Put the log back in
                     IOLog("IOAudioStream[%p]::clipIfNecessary() - Error: already clipped to a position (0x%lx,0x%lx) past data to be clipped (0x%lx, 0x%lx) - data ignored.\n", this, clippedPosition.fLoopCount, clippedPosition.fSampleFrame, clientBufferListStart->mixedPosition.fLoopCount, clientBufferListStart->mixedPosition.fSampleFrame);
                     //clippedPosition.fSampleFrame = clientBufferListStart->mixedPosition.fSampleFrame;
                 }
@@ -1671,10 +1658,8 @@ void IOAudioStream::clipOutputSamples(UInt32 firstSampleFrame, UInt32 numSampleF
 {
     IOReturn result = kIOReturnSuccess;
     
-#ifdef DEBUG_OUTPUT_CALLS
-    //IOLog("IOAudioStream[%p]::clipOutputSamples(0x%lx, 0x%lx)\n", this, firstSampleFrame, numSampleFrames);
-    //IOLog("c(%lx,%lx) %lx\n", firstSampleFrame, numSampleFrames, audioEngine->getCurrentSampleFrame());
-#endif
+    //audioDebugIOLog(6, "IOAudioStream[%p]::clipOutputSamples(0x%lx, 0x%lx)", this, firstSampleFrame, numSampleFrames);
+    //audioDebugIOLog(6, "c(%lx,%lx) %lx", firstSampleFrame, numSampleFrames, audioEngine->getCurrentSampleFrame());
 
     assert(direction == kIOAudioStreamDirectionOutput);
     assert(audioEngine);
@@ -1685,18 +1670,18 @@ void IOAudioStream::clipOutputSamples(UInt32 firstSampleFrame, UInt32 numSampleF
     }
     
 /*
-#ifdef DEBUG_OUTPUT
+#ifdef DEBUG
     UInt32 currentSampleFrame = audioEngine->getCurrentSampleFrame();
     
     if (currentSampleFrame > firstSampleFrame) {
         if ((firstSampleFrame + numSampleFrames) > currentSampleFrame) {
-            //IOLog("IOAudioStream[%p]::clipOutputSamples(0x%lx, 0x%lx) - too late for some samples - current position = 0x%lx.\n", this, firstSampleFrame, numSampleFrames, currentSampleFrame);
-            IOLog("clip(%lx,%lx) missed curr=%lx.\n", firstSampleFrame, numSampleFrames, currentSampleFrame);
+            //audioDebugIOLog(6, "IOAudioStream[%p]::clipOutputSamples(0x%lx, 0x%lx) - too late for some samples - current position = 0x%lx.", this, firstSampleFrame, numSampleFrames, currentSampleFrame);
+            audioDebugIOLog(6, "clip(%lx,%lx) missed curr=%lx.", firstSampleFrame, numSampleFrames, currentSampleFrame);
         }
     } else {
         if ((numSampleFrames + firstSampleFrame) > (currentSampleFrame + audioEngine->getNumSampleFramesPerBuffer())) {
-            //IOLog("IOAudioStream[%p]::clipOutputSamples(0x%lx, 0x%lx) - too late for some samples - current position = 0x%lx.\n", this, firstSampleFrame, numSampleFrames, currentSampleFrame);
-            IOLog("clip(%lx,%lx) missed curr=%lx.\n", firstSampleFrame, numSampleFrames, currentSampleFrame);
+            //audioDebugIOLog(6, "IOAudioStream[%p]::clipOutputSamples(0x%lx, 0x%lx) - too late for some samples - current position = 0x%lx.", this, firstSampleFrame, numSampleFrames, currentSampleFrame);
+            audioDebugIOLog(6, "clip(%lx,%lx) missed curr=%lx.", firstSampleFrame, numSampleFrames, currentSampleFrame);
         }
     }
 #endif
